/*

    file: analyse.h

    Copyright (C) 1998-2004 Christophe GRENIER <grenier@cgsecurity.org>
  
    this software is free software; you can redistribute it and/or modify
    it under the terms of the gnu general public license as published by
    the free software foundation; either version 2 of the license, or
    (at your option) any later version.
  
    this program is distributed in the hope that it will be useful,
    but without any warranty; without even the implied warranty of
    merchantability or fitness for a particular purpose.  see the
    gnu general public license for more details.
  
    you should have received a copy of the gnu general public license
    along with this program; if not, write to the free software
    foundation, inc., 675 mass ave, cambridge, ma 02139, usa.

 */

int search_type_0(t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind);
int search_type_1(t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind);
int search_type_2(t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind);
int search_type_16(t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind);
int search_type_64(t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind);
int search_type_128(t_param_disk *disk_car,t_partition *partition,const int debug, const int dump_ind);
int search_FAT_backup(t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind);
int search_HFS_backup(t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind);
int search_NTFS_backup(t_param_disk *disk_car,t_partition *partition, const int debug, const int dump_ind);
t_list_part *search_superblock(t_param_disk *disk_car, const t_partition *partition, const int debug, const int dump_ind, const int interface);
